@@ -9,6 +9,7 @@ class Upload(ma.fields.Field):
     :param str format: File content encoding (binary, base64).
          Only relevant to OpenAPI 3. Only used for documentation purpose.
     """
-    def __init__(self, format='binary', **kwargs):
+
+    def __init__(self, format="binary", **kwargs):
         self.format = format
         super().__init__(**kwargs)
